
RunScript("system/player_utils.lua"); //has some useful global functions, this is in base

function OnInit() //run upon initialization
	this:GetBrainManager():Add("StandardBase",""); //add this

	//hint to the path-finding system that it can ignore this while computing paths if it needs to
	this:SetIsCreature(true); 
end

function OnPostInit() //run during the entity's first logic update
	LogMsg("Hi World! My name is " .. this:GetName() .. " and I like long romantic walks on the beach");

	this:SetTurnSpeed(6); //turn instantly.  Since we only have 1 graphic frame, it's weird
	//if we don't do this

	//Note: the "always" keyword means the key will always react, regardless of what else is 
	//also pressed. Without it, you couldn't shoot and walk at the same time

	GetInputManager:AddBinding("left,always", "OnLeft", this:GetID());
	GetInputManager:AddBinding("right,always", "OnRight", this:GetID());
	GetInputManager:AddBinding("up,always", "OnUp", this:GetID());
	GetInputManager:AddBinding("down,always", "OnDown", this:GetID());
	
	ResetKeys(); //our function to reset our local key input vars

	//let's have a function that gets run every logic tick
	this:SetRunUpdateEveryFrame(true);
end

function OnKill() //run when removed
	RemoveActivePlayerIfNeeded(this);
end

//this is run every logic tick, normally we don't need to do this, but the player is a special case
function Update(step)
	
	AssignPlayerToCameraIfNeeded(this);  //make us the official player and have the camera track us,
	//if we're not already, and if another entity doesn't already have this role
		
	//this function is in player_utils.lua
	local facing = ConvertKeysToFacing(m_bLeft, m_bRight, m_bUp, m_bDown); 
	
	if (facing != C_FACING_NONE) then
		//they are pressing towards a direction
		this:SetFacingTarget(facing); //turn towards the direction of the keys we pressed
		this:GetBrainManager():SetStateByName("Walk");
	else
		this:GetBrainManager():SetStateByName("Idle");
	end	
end

function ResetKeys()

	m_bLeft = false;
	m_bRight = false;
	m_bUp = false
	m_bDown = false;
end

function OnLeft(bKeyDown)
    m_bLeft = bKeyDown;
	return true; //continue to process key callbacks for this key stroke
end

function OnRight(bKeyDown)
    m_bRight = bKeyDown;
	return true; //continue to process key callbacks for this key stroke
end

function OnUp(bKeyDown)
    m_bUp = bKeyDown;
	return true; //continue to process key callbacks for this key stroke
end

function OnDown(bKeyDown)
    m_bDown = bKeyDown;
	return true; //continue to process key callbacks for this key stroke
end
